Provider Documentation — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »

# Provider Documentation

Authentication Providers supply varying levels of information when authentication has occurred. Some of them can also provide API access tokens in addition to authenticating a user for sign-on. In each provider section, we have outlined how to use each provider as a pyramid plugin and as a part of the velruse standalone application.

- Facebook - `velruse.providers.facebook`
- Github - `velruse.providers.github`
- Google
- Windows Live - `velruse.providers.live`
- Mail.ru - `velruse.providers.mailru`
- OpenID - `velruse.providers.openid`
- Twitter - `velruse.providers.twitter`
- VK - `velruse.providers.vk`
- Yahoo - `velruse.providers.yahoo`
- Yandex - `velruse.providers.yandex`

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »